Reader
======================
This module implements functions to read or export trajectory data from external files. 

.. code:: python

   from pycfrl import reader

.. automodule:: pycfrl.reader
   :members:
   :show-inheritance:
   :special-members: __init__